from .data_types import Column
from .data_types import Table

ID_COLUMN = Column(
    attname="id",
    type_category="U",
    type_name="uuid",
    type_mod=-1,
    not_null=True,
    typelem=0,
)
ENTRY_BASE_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="entry_type",
        type_category="E",
        type_name="entrytype",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="date",
        type_category="D",
        type_name="date",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="meta",
        type_category="U",
        type_name="jsonb",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
)
OPEN_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="currencies",
        type_category="A",
        type_name="varchar",
        type_mod=-1,
        not_null=False,
        # varchar's type oid is 1043
        # ref: https://github.com/postgres/postgres/blob/14dd0f27d7cd56ffae9ecdbe324965073d01a9ff/src/include/catalog/pg_type.dat#L280-L286
        typelem=1043,
    ),
    Column(
        attname="booking",
        type_category="E",
        type_name="booking",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
)
CLOSE_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
)
COMMODITY_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
)
PAD_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="source_account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
)
BALANCE_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="amount_number",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="amount_currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="tolerance",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="diff_number",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="diff_currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
)
TRANSACTION_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="flag",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="payee",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="narration",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="tags",
        type_category="A",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        # varchar's type oid is 1043
        # ref: https://github.com/postgres/postgres/blob/14dd0f27d7cd56ffae9ecdbe324965073d01a9ff/src/include/catalog/pg_type.dat#L280-L286
        typelem=1043,
    ),
    Column(
        attname="links",
        type_category="A",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        # varchar's type oid is 1043
        # ref: https://github.com/postgres/postgres/blob/14dd0f27d7cd56ffae9ecdbe324965073d01a9ff/src/include/catalog/pg_type.dat#L280-L286
        typelem=1043,
    ),
)
POSTING_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="transaction_id",
        type_category="U",
        type_name="uuid",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="units_number",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="units_currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="price_number",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="price_currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="cost_number",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="cost_currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="cost_date",
        type_category="D",
        type_name="date",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="cost_label",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="cost_number_per",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="cost_number_total",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="cost_merge",
        type_category="B",
        type_name="bool",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="flag",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
    Column(
        attname="meta",
        type_category="U",
        type_name="jsonb",
        type_mod=-1,
        not_null=False,
        typelem=0,
    ),
)
NOTE_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="comment",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
)
EVENT_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="type",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="description",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
)
PRICE_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="amount_number",
        type_category="N",
        type_name="numeric",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="amount_currency",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
)
DOCUMENT_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="account",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="filename",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="tags",
        type_category="A",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        # varchar's type oid is 1043
        # ref: https://github.com/postgres/postgres/blob/14dd0f27d7cd56ffae9ecdbe324965073d01a9ff/src/include/catalog/pg_type.dat#L280-L286
        typelem=1043,
    ),
    Column(
        attname="links",
        type_category="A",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        # varchar's type oid is 1043
        # ref: https://github.com/postgres/postgres/blob/14dd0f27d7cd56ffae9ecdbe324965073d01a9ff/src/include/catalog/pg_type.dat#L280-L286
        typelem=1043,
    ),
)
CUSTOM_TABLE: Table = (
    ID_COLUMN,
    Column(
        attname="type",
        type_category="S",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        typelem=0,
    ),
    Column(
        attname="values",
        type_category="A",
        type_name="varchar",
        type_mod=-1,
        not_null=True,
        # varchar's type oid is 1043
        # ref: https://github.com/postgres/postgres/blob/14dd0f27d7cd56ffae9ecdbe324965073d01a9ff/src/include/catalog/pg_type.dat#L280-L286
        typelem=1043,
    ),
)
